#!/bin/sh

INSTALL_DIR=/opt

setupModuleForDaemontools() {
	if [ $# -ne 1 ]; then
		return 1
	fi

	local module_name=$1
	if [ -e $INSTALL_DIR/package/daemontools/$module_name ]; then
		/bin/cp -r $INSTALL_DIR/package/daemontools/$module_name $INSTALL_DIR/aile/service/
		if [ ! -e  $INSTALL_DIR/aile/service/$module_name/run ]; then
			cd $INSTALL_DIR/aile/service/$module_name
			if [ -e run_$module_name.sh ]; then
				/bin/chmod +x run_$module_name.sh
				/bin/ln -s run_$module_name.sh run
			fi
			cd $CURDIR
		fi
		/bin/chown aile:aile $INSTALL_DIR/aile/service/$module_name $INSTALL_DIR/aile/service/run_$module_name.sh
		if [ ! -e /etc/service/$module_name ]; then
			/bin/ln -fs $INSTALL_DIR/aile/service/$module_name /etc/service/$module_name
		fi
		# サービスの再起動
		if [ $(/usr/bin/sudo /usr/bin/svstat /etc/service/$module_name | /usr/bin/awk '{print $2}') = "down" ]; then
			/usr/bin/sudo /usr/bin/svc -u /etc/service/$module_name
		fi
	fi

	return 0
}

purgePackage() {
	if [ $# -ne 1 ]; then
		return 1
	fi

	local package_name=$1

	/usr/bin/dpkg -l $package_name
	status=`echo $?`
	if [ $status -eq 0 ]; then
		logger -t purgePackage "$package_name purge"
		/usr/bin/dpkg --purge $package_name
	fi
}

if [ $# -gt 0 -a -d $1 ] ; then
	INSTALL_DIR=$1
fi

if [ $(/bin/cat /etc/group | /bin/grep video | /bin/grep aile | wc -l) -eq 0 ]; then
	/usr/sbin/usermod -a -G video aile
fi

HWWATCHDOG_PKG=$INSTALL_DIR/watchdog
if [ -d $HWWATCHDOG_PKG ]; then
	cd $HWWATCHDOG_PKG
	sh install.sh
	cd ..
	/bin/rm -fr $HWWATCHDOG_PKG
fi

DRIVER_PKG=$INSTALL_DIR/driver
if [ -d $DRIVER_PKG ] ;  then
	cd $DRIVER_PKG
	sh install.sh
	cd ..
	/bin/rm -rf $DRIVER_PKG
fi

if [ -e /opt/REQUIRE_REBOOT ]; then
	rm /opt/REQUIRE_REBOOT
	logger -t driver_update "reboot check"
	reboot
fi

if [ ! -e $INSTALL_DIR/aile/sources.list.org ]; then
	if [ -e /etc/apt/sources.list ]; then
		/bin/mv /etc/apt/sources.list $INSTALL_DIR/aile/sources.list.org
	fi
fi
if [ -e $INSTALL_DIR/package/sources.list ]; then
	if [ ! -e /etc/apt/sources.list ]; then
		/bin/cp $INSTALL_DIR/package/sources.list /etc/apt/sources.list
	fi
fi

purgePackage "whoopsie"

/usr/bin/dpkg -i $INSTALL_DIR/package/release64/*.deb

/usr/bin/dpkg -i $INSTALL_DIR/package/onvif/*.deb

if [ -e $INSTALL_DIR/package/dnsmasq ]; then
	/usr/bin/dpkg -i $INSTALL_DIR/package/dnsmasq/*.deb	
fi

if [ ! -e $INSTALL_DIR/aile/service ]; then
	/bin/mkdir -p $INSTALL_DIR/aile/service
fi

# daemontoolで起動するモジュールをインストール
CURDIR=`pwd`
if [ $(/usr/bin/which svstat) != "" ]; then
	setupModuleForDaemontools "checkprocess"
	setupModuleForDaemontools "outputsensorinfo"
	setupModuleForDaemontools "remocon"
fi

# thickness.confをconfigの下に移動
# 初回のみ
if [ -e $INSTALL_DIR/package/thickness.conf ]; then
	if [ ! -e $INSTALL_DIR/aile/config/thickness.conf ]; then
		/bin/cp $INSTALL_DIR/package/thickness.conf $INSTALL_DIR/aile/config/thickness.conf
		/bin/chmod 666 $INSTALL_DIR/aile/config/thickness.conf
		/bin/chown aile:aile $INSTALL_DIR/aile/config/thickness.conf
	fi
	if [ ! -e $INSTALL_DIR/aile/thickness.conf.default ]; then
		/bin/cp $INSTALL_DIR/package/thickness.conf $INSTALL_DIR/aile/thickness.conf.default
		/bin/chmod 666 $INSTALL_DIR/aile/thickness.conf.default
		/bin/chown aile:aile $INSTALL_DIR/aile/thickness.conf.default
	fi
fi

# DNS対応(DNSキャッシュサーバの設定)
if [ -e $INSTALL_DIR/package/dnsmasq.conf ]; then
	if [ ! -e /etc/dnsmasq.conf.org ]; then
		/bin/mv /etc/dnsmasq.conf /etc/_dnsmasq.conf.org
	fi
	if [ ! -e /etc/dnsmasq.conf ]; then
		/bin/cp $INSTALL_DIR/package/dnsmasq.conf /etc/dnsmasq.conf
		/etc/init.d/dnsmasq restart
	fi
	/bin/chmod 666 /etc/dnsmasq.conf
fi
# DNS対応
if [ -e $INSTALL_DIR/package/resolv-head.conf ]; then
	if [ ! -e $INSTALL_DIR/aile/resolv-head.conf.default ]; then
		/bin/cp $INSTALL_DIR/package/resolv-head.conf $INSTALL_DIR/aile/resolv-head.conf.default
	fi
	if [ ! -e $INSTALL_DIR/aile/config/resolv-head.conf ]; then
		/bin/cp $INSTALL_DIR/package/resolv-head.conf $INSTALL_DIR/aile/config/resolv-head.conf
	fi
	if [ ! -e /etc/resolvconf/resolv.conf.d/head.org ]; then
		/bin/mv /etc/resolvconf/resolv.conf.d/head /etc/resolvconf/resolv.conf.d/head.org
	fi
	/bin/chmod 666 $INSTALL_DIR/aile/config/resolv-head.conf
	/bin/chown aile:aile $INSTALL_DIR/aile/config/resolv-head.conf
	/bin/ln -fs $INSTALL_DIR/aile/config/resolv-head.conf /etc/resolvconf/resolv.conf.d/head
fi

if [ -e $INSTALL_DIR/package/resolv-tail.conf ]; then
	if [ ! -e $INSTALL_DIR/aile/config/resolv-tail.conf ]; then
		/bin/cp $INSTALL_DIR/package/resolv-tail.conf $INSTALL_DIR/aile/config/resolv-tail.conf
	fi
	if [ -e $INSTALL_DIR/aile/add_dns_options.sh ]; then
		/bin/bash $INSTALL_DIR/aile/add_dns_options.sh $INSTALL_DIR/aile/config/resolv-tail.conf
	fi
	/bin/chmod 666 $INSTALL_DIR/aile/config/resolv-tail.conf
	/bin/chown aile:aile $INSTALL_DIR/aile/config/resolv-tail.conf
	/bin/ln -fs $INSTALL_DIR/aile/config/resolv-tail.conf /etc/resolvconf/resolv.conf.d/tail
fi
/sbin/resolvconf -u

# Zabbixの設定ファイルをconfigの下に移動
if [ -e $INSTALL_DIR/package/zabbix/zabbix_agentd-temp.conf ]; then
	if [ ! -e $INSTALL_DIR/aile/zabbix ]; then
		/bin/mkdir -p $INSTALL_DIR/aile/zabbix
	fi
	/bin/cp $INSTALL_DIR/package/zabbix/zabbix_agentd-temp.conf $INSTALL_DIR/aile/zabbix/zabbix_agentd-temp.conf
fi
if [ -e /etc/zabbix/zabbix_agentd.conf ]; then
	if [ ! -L /etc/zabbix/zabbix_agentd.conf ]; then
		/bin/mv /etc/zabbix/zabbix_agentd.conf $INSTALL_DIR/aile/config/zabbix_agentd.conf
		/bin/cp $INSTALL_DIR/aile/config/zabbix_agentd.conf $INSTALL_DIR/aile/zabbix/zabbix_agentd.conf.org
		/bin/ln -fs $INSTALL_DIR/aile/config/zabbix_agentd.conf /etc/zabbix/zabbix_agentd.conf
		/bin/chown aile:aile $INSTALL_DIR/aile/config/zabbix_agentd.conf
	fi
fi

# sudoersの更新
if [ -e $INSTALL_DIR/package/aile-sudoers ]; then
	diffStatus=`/usr/bin/diff $INSTALL_DIR/package/aile-sudoers /etc/sudoers.d/aile-sudoers`
	if [ "$diffStatus" != "" ]; then
		/bin/chmod 664 /etc/sudoers.d/aile-sudoers
		/bin/cp $INSTALL_DIR/package/aile-sudoers /etc/sudoers.d/aile-sudoers
		/bin/chmod 440 /etc/sudoers.d/aile-sudoers
	fi
fi

if [ ! -e /etc/modules.org ]; then
	/bin/cp /etc/modules /etc/modules.org
fi
if [ -e $INSTALL_DIR/package/modules.conf ]; then
	if [ -e /etc/modules.org ]; then
		/bin/cp -f /etc/modules.org /etc/modules
	fi
	/bin/cat $INSTALL_DIR/package/modules.conf >> /etc/modules
fi
/bin/rm -rf $INSTALL_DIR/package

setcap cap_net_raw=ep $INSTALL_DIR/aile/IpChecker
setcap cap_net_admin=ep $INSTALL_DIR/aile/MyNetworkSetting
setcap cap_sys_time,cap_dac_override=ep $INSTALL_DIR/aile/MyClockSetting
setcap cap_setuid,cap_setgid,cap_sys_admin,CAP_FOWNER=ep $INSTALL_DIR/aile/automount
setcap cap_sys_rawio,cap_dac_read_search=ep $INSTALL_DIR/aile/hwcheck
setcap cap_setuid,cap_setgid,cap_sys_admin,cap_net_admin,CAP_FOWNER,cap_kill=ep $INSTALL_DIR/aile/checkprocess
setcap cap_setuid,cap_setgid=ep $INSTALL_DIR/aile/OutputLog
setcap cap_setuid,cap_setgid=ep $INSTALL_DIR/aile/OutputSensorInfo
setcap cap_net_admin=ep $INSTALL_DIR/aile/arpdel
setcap cap_sys_rawio,cap_dac_read_search,cap_dac_override=ep $INSTALL_DIR/aile/remocon
setcap cap_sys_time,cap_dac_override=ep $INSTALL_DIR/aile/syncClock
/bin/rm -f /etc/cron.hourly/syncClock
/bin/mv $INSTALL_DIR/aile/ntpdate /etc/network/if-up.d/ntpdate
/bin/ln -s /etc/network/if-up.d/ntpdate /etc/cron.hourly/ntpdate

CRONTAB_FILE=/etc/crontab
CRONTAB_ORIGINAL_FILE=/etc/crontab.org

if [ ! -e $CRONTAB_ORIGINAL_FILE ]; then
	/bin/cp $CRONTAB_FILE $CRONTAB_ORIGINAL_FILE
fi
if [ -e $CRONTAB_ORIGINAL_FILE ]; then
	ALREADYCONF=`/bin/cat $CRONTAB_ORIGINAL_FILE | /bin/grep "@reboot root /etc/cron.hourly/ntpdate FORCE"`
	if [ -z $ALREADYCONF ]; then
		/bin/cp $CRONTAB_ORIGINAL_FILE $CRONTAB_FILE
		/bin/echo "@reboot root /etc/cron.hourly/ntpdate FORCE" >> $CRONTAB_FILE
	fi
fi


/bin/echo "export GTK2_RC_FILES=$INSTALL_DIR/aile/ui/gtkrc" >> $INSTALL_DIR/aile/startup.sh
/bin/echo "sleep 10" >> $INSTALL_DIR/aile/startup.sh
/bin/echo "cd $INSTALL_DIR/aile ; ./aile &" >> $INSTALL_DIR/aile/startup.sh
/bin/echo "$INSTALL_DIR/aile/packcore.sh" >> $INSTALL_DIR/aile/startup.sh

AILE_LOCALE=$INSTALL_DIR/locale

if [ -d $AILE_LOCALE ] ; then
	/bin/cp -rfv $AILE_LOCALE /usr/local/share/
	/bin/rm -rf $AILE_LOCALE
fi

H264_PKG=$INSTALL_DIR/h264
MJPG_PKG=$INSTALL_DIR/mjpg
H264_EXTRA_PKG=$INSTALL_DIR/h264_extra
AILE_EXCTRL_PKG=$INSTALL_DIR/aile_exctrl

if [ -d $H264_PKG ] ;  then
	cd $H264_PKG
	sh install.sh
	cd ..
	/bin/rm -rf $H264_PKG
fi

if [ -d $MJPG_PKG ] ;  then
	cd $MJPG_PKG
	sh install.sh
	cd ..
	/bin/rm -rf $MJPG_PKG
fi

if [ -d $H264_EXTRA_PKG ] ;  then
	cd $H264_EXTRA_PKG
	make install_lib
	cd ..
	/bin/rm -rf $H264_EXTRA_PKG
fi

if [ -d $AILE_EXCTRL_PKG ] ;  then
	cd $AILE_EXCTRL_PKG
	sh install.sh
	cd ..
	/bin/rm -rf $AILE_EXCTRL_PKG
fi

# configのgtkrcをコピー
if [ -e $INSTALL_DIR/aile/config/gtkrc.conf ]; then
	/bin/cp -f $INSTALL_DIR/aile/config/gtkrc.conf $INSTALL_DIR/aile/ui/gtkrc
fi
